notetools.make_repeated_notes_from_time_signatures
==================================================

.. autofunction:: abjad.tools.notetools.make_repeated_notes_from_time_signatures.make_repeated_notes_from_time_signatures
